@@ -26,10 +26,9 @@ class MailImporter::FilterEvolution_v3Private
 {
 public:
     FilterEvolution_v3Private()
-        : mImportDirDone(-1),
-          mTotalDir(-1)
+        : mImportDirDone(-1)
+        , mTotalDir(-1)
     {
-
     }
 
     int mImportDirDone;
@@ -42,8 +41,8 @@ FilterEvolution_v3::FilterEvolution_v3()
              i18n("<p><b>Evolution 3.x import filter</b></p>"
                   "<p>Select the base directory of your local Evolution mailfolder (usually ~/.local/share/evolution/mail/local/).</p>"
                   "<p>Since it is possible to recreate the folder structure, the folders "
-                  "will be stored under: \"Evolution-Import\".</p>")),
-      d(new MailImporter::FilterEvolution_v3Private)
+                  "will be stored under: \"Evolution-Import\".</p>"))
+    , d(new MailImporter::FilterEvolution_v3Private)
 {
 }
 
@@ -68,7 +67,7 @@ void FilterEvolution_v3::import()
         evolDir = QDir::homePath();
     }
 
-    const QString dir = QFileDialog::getExistingDirectory(0, QString(), evolDir);
+    const QString dir = QFileDialog::getExistingDirectory(nullptr, QString(), evolDir);
     if (!dir.isEmpty()) {
         importMails(dir);
     }
@@ -86,11 +85,10 @@ void FilterEvolution_v3::processDirectory(const QString &path)
         if (!(*filename == QLatin1String(".") || *filename == QLatin1String(".."))) {
             filterInfo()->setCurrent(0);
             importDirContents(dir.filePath(*filename));
-            filterInfo()->setOverall((d->mTotalDir > 0) ? (int)((float) d->mImportDirDone / d->mTotalDir * 100) : 0);
+            filterInfo()->setOverall((d->mTotalDir > 0) ? (int)((float)d->mImportDirDone / d->mTotalDir * 100) : 0);
             filterInfo()->setCurrent(100);
         }
     }
-
 }
 
 void FilterEvolution_v3::importMails(const QString &maildir)
@@ -137,7 +135,6 @@ void FilterEvolution_v3::importMails(const QString &maildir)
  */
 void FilterEvolution_v3::importDirContents(const QString &dirName)
 {
-
     /** Here Import all archives in the current dir */
     importFiles(dirName);
 
@@ -152,7 +149,6 @@ void FilterEvolution_v3::importDirContents(const QString &dirName)
  */
 void FilterEvolution_v3::importFiles(const QString &dirName)
 {
-
     QDir dir(dirName);
     QString _path;
     bool generatedPath = false;
@@ -168,10 +164,10 @@ void FilterEvolution_v3::importFiles(const QString &dirName)
         }
         QString temp_mailfile = *mailFile;
         if (!(temp_mailfile.endsWith(QLatin1String(".db"))
-                || temp_mailfile.endsWith(QLatin1String(".cmeta"))
-                || temp_mailfile.endsWith(QLatin1String(".ev-summary"))
-                || temp_mailfile.endsWith(QLatin1String(".ibex.index"))
-                || temp_mailfile.endsWith(QLatin1String(".ibex.index.data")))) {
+              || temp_mailfile.endsWith(QLatin1String(".cmeta"))
+              || temp_mailfile.endsWith(QLatin1String(".ev-summary"))
+              || temp_mailfile.endsWith(QLatin1String(".ibex.index"))
+              || temp_mailfile.endsWith(QLatin1String(".ibex.index.data")))) {
             if (!generatedPath) {
                 _path = i18nc("define folder name where we import evolution mails", "Evolution-Import");
                 QString _tmp = dir.filePath(*mailFile);
@@ -207,7 +203,7 @@ void FilterEvolution_v3::importFiles(const QString &dirName)
             if (!importMessage(_path, dir.filePath(*mailFile), filterInfo()->removeDupMessage(), status)) {
                 filterInfo()->addErrorLogEntry(i18n("Could not import %1", *mailFile));
             }
-            filterInfo()->setCurrent((int)((float) currentFile / numFiles * 100));
+            filterInfo()->setCurrent((int)((float)currentFile / numFiles * 100));
         }
     }
 }
@@ -233,4 +229,3 @@ MailImporter::MessageStatus FilterEvolution_v3::statusFromFile(const QString &fi
     }
     return status;
 }
-
